Mode

Enum Mode 

pub enum Mode {
    Zen,
    Patient,
    Immediate,
}
The strategy used by an Emulator when waiting for tasks to finish.

A Mode can be used to make an Emulator wait for side effects to finish before continuing execution.

Variants



Zen

Waits for all tasks spawned by an Instruction, as well as all tasks indirectly spawned by the the results of those tasks.

This is the default.



Patient

Waits only for the tasks directly spawned by an Instruction.



Immediate

Never waits for any tasks to finish.

Implementations

Source

impl Mode

pub const ALL: &[Self]

A list of all the available modes.