pub enum Expectation {
Text(String),
Focused(Target),
}Expand description
A testing assertion.
Expectations are instructions that verify the current state of the user interface of an application.
Variants
Text(String)
Expect some element to contain some text.
Focused(Target)
Expect a widget with the given text or id to have keyboard focus.