pub enum Interaction {
Mouse(Mouse),
Keyboard(Keyboard),
}Expand description
A user interaction.
Variants
Implementations
Sourceimpl Interaction
impl Interaction
Sourcepub fn from_event(event: &Event) -> Option<Self>
pub fn from_event(event: &Event) -> Option<Self>
Creates an Interaction from a runtime Event.
This can be useful for recording tests during real usage.
Sourcepub fn merge(self, next: Self) -> (Self, Option<Self>)
pub fn merge(self, next: Self) -> (Self, Option<Self>)
Merges two interactions together, if possible.
This method can turn certain sequences of interactions into a single one. For instance, a mouse movement, left button press, and left button release can all be merged into a single click interaction.
Merging is lossy and, therefore, it is not always desirable if you are recording a test and want full reproducibility.
If the interactions cannot be merged, the next interaction will be
returned as the second element of the tuple.