Simulator

Struct Simulator 

pub struct Simulator<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }
A user interface that can be interacted with and inspected programmatically.

Implementations

Source

impl<'a, Message, Theme, Renderer> Simulator<'a, Message, Theme, Renderer>
where Theme: Base, Renderer: Renderer + Headless,

pub fn new(element: impl Into<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a new Simulator with default Settings and a default size (1024x768).

pub fn with_settings( settings: Settings, element: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self

Creates a new Simulator with the given Settings and a default size (1024x768).

pub fn with_size( settings: Settings, size: impl Into<Size>, element: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self

Creates a new Simulator with the given Settings and size.

pub fn find<S>(&mut self, selector: S) -> Result<S::Output, Error>
where S: Selector + Send, S::Output: Clone + Send,

Finds the target of the given widget Selector in the Simulator.

pub fn point_at(&mut self, position: impl Into<Point>)

Points the mouse cursor at the given position in the Simulator.

This does not produce mouse movement events!

pub fn click<S>(&mut self, selector: S) -> Result<S::Output, Error>
where S: Selector + Send, S::Output: Bounded + Clone + Send + Sync + 'static,

Clicks the Bounded target found by the given Selector, if any.

This consists in:

  • Pointing the mouse cursor at the center of the Bounded target.
  • Simulating a click.
pub fn tap_key(&mut self, key: impl Into<Key>) -> Status

Simulates a key press, followed by a release, in the Simulator.

pub fn typewrite(&mut self, text: &str) -> Status

Simulates a user typing in the keyboard the given text in the Simulator.

pub fn simulate( &mut self, events: impl IntoIterator<Item = Event>, ) -> Vec<Status>

Simulates the given raw sequence of events in the Simulator.

pub fn snapshot(&mut self, theme: &Theme) -> Result<Snapshot, Error>

Draws and takes a Snapshot of the interface in the Simulator.

pub fn into_messages( self, ) -> impl Iterator<Item = Message> + use<Message, Theme, Renderer>

Turns the Simulator into the sequence of messages produced by any interactions.