Snapshot

Struct Snapshot 

pub struct Snapshot { /* private fields */ }
A frame of a user interface rendered by a Simulator.

Implementations

Source

impl Snapshot

pub fn matches_image(&self, path: impl AsRef<Path>) -> Result<bool, Error>

Compares the Snapshot with the PNG image found in the given path, returning true if they are identical.

If the PNG image does not exist, it will be created by the Snapshot for future testing and true will be returned.

pub fn matches_hash(&self, path: impl AsRef<Path>) -> Result<bool, Error>

Compares the Snapshot with the SHA-256 hash file found in the given path, returning true if they are identical.

If the hash file does not exist, it will be created by the Snapshot for future testing and true will be returned.