pub struct AccessibleMatch {
pub id: Option<Id>,
pub bounds: Rectangle,
pub visible_bounds: Option<Rectangle>,
pub role: Role,
pub label: Option<String>,
pub description: Option<String>,
}Expand description
A widget match produced by an accessibility selector.
Fields
id: Option<Id>The widget Id, if any.
bounds: RectangleThe layout bounds of the matched widget.
visible_bounds: Option<Rectangle>The visible bounds of the matched widget, in screen coordinates.
role: RoleThe accessible Role of the matched widget.
label: Option<String>The accessible label of the matched widget, if any.
description: Option<String>The accessible description of the matched widget, if any.
Implementations
Sourceimpl AccessibleMatch
impl AccessibleMatch
Sourcepub fn bounds(&self) -> Rectangle
pub fn bounds(&self) -> Rectangle
Returns the layout bounds of the AccessibleMatch.
Sourcepub fn visible_bounds(&self) -> Option<Rectangle>
pub fn visible_bounds(&self) -> Option<Rectangle>
Returns the visible bounds of the AccessibleMatch, in screen coordinates.