pub enum Mode {
Zen,
Patient,
Immediate,
}Expand description
Variants
Zen
Waits for all tasks spawned by an Instruction, as well as all tasks indirectly
spawned by the the results of those tasks.
This is the default.
Patient
Waits only for the tasks directly spawned by an Instruction.
Immediate
Never waits for any tasks to finish.
Implementations