pub type FindAll<S> = Finder<All<S>>;
An Operation that runs the Selector for the entire widget tree and aggregates all of its Output.
Operation
Selector
Output
pub struct FindAll<S> { /* private fields */ }